Py4JNetworkException.ErrorTime (py4j-java 0.10.9.4 API)
Date: 2022-03-16

py4j

## Enum Py4JNetworkException.ErrorTime

- java.lang.Object
- - java.lang.Enum<Py4JNetworkException.ErrorTime>
  - - py4j.Py4JNetworkException.ErrorTime

- All Implemented Interfaces:
    java.io.Serializable, java.lang.Comparable<Py4JNetworkException.ErrorTime>
  Enclosing class:
    Py4JNetworkException

      public static enum Py4JNetworkException.ErrorTime
      extends java.lang.Enum<Py4JNetworkException.ErrorTime>

- - ### Enum Constant Summary

    Enum Constants
    Enum Constant and Description
    `ERROR_ON_RECEIVE`
    `ERROR_ON_SEND`
    `OTHER`

  - ### Method Summary

    All Methods Static Methods Concrete Methods
    Modifier and Type | Method and Description
    --- | ---
    `static Py4JNetworkException.ErrorTime` | `valueOf(java.lang.String name)` Returns the enum constant of this type with the specified name.
    `static Py4JNetworkException.ErrorTime[]` | `values()` Returns an array containing the constants of this enum type, in the order they are declared.

    - ### Methods inherited from class java.lang.Enum

      `clone, compareTo, equals, finalize, getDeclaringClass, hashCode, name, ordinal, toString, valueOf`

    - ### Methods inherited from class java.lang.Object

      `getClass, notify, notifyAll, wait, wait, wait`

- - ### Enum Constant Detail

    - #### ERROR_ON_SEND

          public static final Py4JNetworkException.ErrorTime ERROR_ON_SEND

    - #### ERROR_ON_RECEIVE

          public static final Py4JNetworkException.ErrorTime ERROR_ON_RECEIVE

    - #### OTHER

          public static final Py4JNetworkException.ErrorTime OTHER

  - ### Method Detail

    - #### values

          public static Py4JNetworkException.ErrorTime[] values()

      Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:

          for (Py4JNetworkException.ErrorTime c : Py4JNetworkException.ErrorTime.values())
              System.out.println(c);

      Returns:
        an array containing the constants of this enum type, in the order they are declared

    - #### valueOf

          public static Py4JNetworkException.ErrorTime valueOf(java.lang.String name)

      Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
      Parameters:
        `name` - the name of the enum constant to be returned.
      Returns:
        the enum constant with the specified name
      Throws:
        `java.lang.IllegalArgumentException` - if this enum type has no constant with the specified name
        `java.lang.NullPointerException` - if the argument is null